#
# spec file for package python-dfVFS
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define timestamp 20171230
Name:           python-dfVFS
Version:        0~%{timestamp}
Release:        lp150.1.3
Summary:        Digital Forensics Virtual File System
License:        Apache-2.0
Group:          Productivity/File utilities
Url:            https://github.com/log2timeline/dfvfs/wiki
Source:         https://github.com/log2timeline/dfvfs/releases/download/%timestamp/dfvfs-%timestamp.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-rpm-macros
BuildRequires:  python-setuptools
Requires:       python-construct
Requires:       python-pycrypto
# Use the python- variant of the libyal python bindings.  This allows python singlespec to tweak the Requires for python2 and python3
Requires:       python-six
Requires:       python2-dfdatetime >= 0~20180110
Requires:       python2-libbde
Requires:       python2-libewf
Requires:       python2-libfsntfs >= 0~20160418
Requires:       python2-libfvde
Requires:       python2-libfwnt
Requires:       python2-libqcow
Requires:       python2-libsigscan
Requires:       python2-libsmdev
Requires:       python2-libsmraw
Requires:       python2-libvhdi
Requires:       python2-libvmdk
Requires:       python2-libvshadow >= 0~20170902
Requires:       python2-libvslvm
Requires:       python2-tsk >= 0~20160721
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
dfVFS, or Digital Forensics Virtual File System, provides read-only access to file-system objects from various storage media types and file formats. The goal of dfVFS is to provide a generic interface for accessing file-system objects, for which it uses several back-ends that provide the actual implementation of the various storage media types, volume systems and file systems.

dfVFS originates from the Plaso project and is also based on ideas from the GRR project. It was largely rewritten and made into a stand-alone project to provide more flexibility and allow other projects to make use of the VFS functionality. dfVFS originally was named PyVFS, but that name conflicted with another project.

dfVFS is currently implemented as a Python module.

%prep
%setup -q -n dfvfs-%{timestamp}
find dfvfs -name \*.py | xargs sed -i "/#!\/usr\/bin\/python/d"
chmod -x utils/check_dependencies.py
chmod -x run_tests.py

%build
python setup.py build

%install
python setup.py install --root=%{buildroot} --prefix=%{_prefix}
# force complie to resolve an rpmlint complaint
pushd %{buildroot}%{python_sitelib}/dfvfs/
%py_compile .
%py_compile serializer
popd
%fdupes -s %{buildroot}

%files
%defattr(-,root,root)
%doc ACKNOWLEDGEMENTS AUTHORS LICENSE README
%doc utils/check_dependencies.py utils/dependencies.py
%doc examples
%{python_sitelib}/dfvfs-%{timestamp}-py2.7.egg-info
%{python_sitelib}/dfvfs
# these are installed into the wrong place
%exclude %{_datadir}/doc/dfvfs/

%changelog
* Thu Jan 11 2018 Greg.Freemyer@gmail.com
- update to v0~20171230
  * add more python3 support (even though openSUSE package doesn't use it)
  * bug fixes
  * compatible with plaso 20171231
- revert effort to use Python singlespec.  It's just not working smoothly.
* Mon Oct  2 2017 Greg.Freemyer@gmail.com
- update to v0~20170723
  * worked on internal test structure
- add python3 support
- implement python singlespec syntax
- In Requires: lines for libyal python bindings, use the python-lib* variant of the package
  Python singlespec automatically converts that to python2 / python3 as appropriate
- remove Requres: python-protobuf.  It has been replaced by a JSON solution
- adopt upstream name of python{23}-tsk3
* Sun Feb 26 2017 Greg.Freemyer@gmail.com
- correct Requires to have 0~ prefix
* Thu Jul 14 2016 Greg.Freemyer@gmail.com
- update to v0~20160918
  * still pre-release and no ChangeLog available
  * add requires pyfwnt, pyvslvm, python-dfdatetime
* Wed Dec  2 2015 Greg.Freemyer@gmail.com
- update to v0~20160108
  * still pre-release and no ChangeLog available
  * required by plaso v1.4.0 which is in feature freeze at this point
- update pyvshadow requires to version v0~20160110
- add Requires: pyfsntfs
* Wed Jul  1 2015 Greg.Freemyer@gmail.com
- update to v0~20150708
  * warning, breaks plaso prior to v1.3.0rc2
  * still pre-release and no ChangeLog available
* Fri May  8 2015 Greg.Freemyer@gmail.com
- update to v0~20150408
  * Plaso is the primary consumer of dfVFS, but it can be used standalone and may have other consumers in the future
  * Warning breaks JSON serialization in plaso and require a plaso version of 20150507 or later.
* Wed Mar 25 2015 Greg.Freemyer@gmail.com
- update to v0~20150303
  * dfVFS is in a rapid state of development and Changelog entries have not been implemented by upstream
- add Requires: pysigscan, it is a new dependency
- add a new %%exclude in %%files due to doubly included %%doc files
- remove spec file entry deleting installed examples.  Resolved upstream.
  * see https://github.com/log2timeline/dfvfs/issues/4
- chmod run_tests.py to remove the executable bits.  Was causing a rmplint warning.
* Wed Jan 21 2015 Greg.Freemyer@gmail.com
- update to v0~20150108
  * bugfix for auto-dependency build
- add explicit "%%py_compile ." to resolve rpmlint complaint about datestamps not matching
- add the examples folder to the %%doc section of %%files
- add run_tests.py to the %%doc section of %%files
* Mon Dec 22 2014 Greg.Freemyer@gmail.com
- upgrade to v0~20141220
  * dfVFS is in a rapid state of development and Changelog entries have not been implemented by upstream
- v0~20141220 required by latest plaso release
- update Url field to point to the new github site
- update source to be complete URL
- delete DL_URL field
- add an exclude for the "examples" that are provided.  They need a better namespace.
- add check_dependencies.py to %%doc so that users can verify they have usable dependencies
* Thu Aug 21 2014 Greg.Freemyer@gmail.com
- add a %%doc line to %%files section
- change the license tag to Apache-2.0
- add Requires libvmdk since it is now in OBS
- add Requires libvhdi since it is now in OBS
* Wed Aug 20 2014 Greg.Freemyer@gmail.com
- add missing "Requires: pyqcow" line to specfile
- remove %%attr(755...) line and instead use sed to remove #!/usr/bin/python from *py files
- cleanup Requires: in general
* Mon Aug 18 2014 Greg.Freemyer@gmail.com
- initial version in OBS (version 0~20140727)
